#
# spec file for package python-cloudflare
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-cloudflare
Version:        2.12.4
Release:        1.1
Summary:        Python wrapper for the Cloudflare v4 API
License:        MIT
URL:            https://github.com/cloudflare/python-cloudflare
Source:         https://files.pythonhosted.org/packages/source/c/cloudflare/cloudflare-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module jsonlines}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests >= 2.4.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-beautifulsoup4
Requires:       python-jsonlines
Requires:       python-requests >= 2.4.2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Python wrapper for the Cloudflare Client API v4.

%prep
%setup -q -n cloudflare-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/cli4
%python_clone -a %{buildroot}%{_mandir}/man1/cli4.1
# remove examples from sitelib
%python_expand rm -rf %{buildroot}%{$python_sitelib}/examples
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#%%check
# there is one test, but even upstream does not launch it

%post
%python_install_alternative cli4 cli4.1

%postun
%python_uninstall_alternative cli4 cli4.1

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/cli4
%python_alternative %{_mandir}/man1/cli4.1
%{python_sitelib}/CloudFlare
%{python_sitelib}/cli4
%{python_sitelib}/cloudflare-%{version}.dist-info

%changelog
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 2.12.4:
  * added ips and issue114 tests
  * add importlib_resources info for older Python versions
  * more api endpoints
  * more twine tweaks
  * Added cli4 -e option to
    display example file path names
  * Add `global_request_timeout` and `max_request_retries`
    configuration options. Set default request timeout to 5s. Add
    basic tests instantiating Cloudflare.Cloudflare
  * more api endpoints
  * Make RegEx string a raw string literal
  * more api endpoints
  * update examples and README to use == for numberic values
  * more api endpoints
  * remove --api option and leave --openapi in place
  * handle quoted strings
  * handle multipart/form-data
    correctly for more than one file and with params/data
  * python keywords not handled correctly at command level
  * fix: remove future dependency and imports
  * added after openapi review
  * added deprecated processing, now shows version
* Tue Sep  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
- Drop unneeded {Build,}Requires on future.
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.11.7:
  * more api endpoints
  * update examples and README to use == for numberic values
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 2.11.6:
  * handle multipart/form-data correctly for more than one file and with params/data
  * keywords not handled correctly at command level
  * added after openapi review
  * added deprecated processing, now shows version
* Sat Jul  1 2023 ecsos <ecsos@opensuse.org>
- Update to 2.11.1
  - more api endpoints
  - firewall rules example
  - add openapi support, added tuna for testing
  - add openapi support, delay yaml and jsonlines load to speed up everything, other cleanup
  - add openapi support, delay bs4 load to speed up everything, improve requests imports
  - missing import json, speed up to import requests
  For full changelog see:
  https://github.com/cloudflare/python-cloudflare/blob/master/CHANGELOG.md
- Add %%{?sle15_python_module_pythons}
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.8.15:
  * added cursor example
  * zones/rulesets added
  * Removing excess trailing parenthesis
  * first pass at adding travis CI
  * zones/waiting_rooms, accounts/diagnostics, and more
  * configparser added it haste, but not needed - oops!
  * /zones/:id/access/...
  * configparser missing - oops!
  * cleaner and easier way to find missing api calls - this changes --dump/--api for the better
  * /zones/:id/access/apps/policies - fixed along with a bunch more similar typos
  * added more profile info
  * revoke-tokens -> revoke_tokens
  * updated and included AMP RealURL/Signed Exchange API
  * now with curl style debug - i.e. matches api information page
  * now with curl style debug - i.e. matches api information page
  * now with access_requests as underscore
  * make sure verbose, etc is always used
  * dashes vs underscores - finally tamed!
  * /zones/:id/access/apps/:id/revoke-tokens - added
  * improve deprecated code - add dates, check expire, improve parse of api webpage
  * added support for dashes/underscores in commands and python calls - kinda overdue
  * cleanup of logic around uuid match. added support for dashes/underscores in commands
  * /zones/:id/access/apps/revoke-tokens - removed as depricated
  * removed deprecated /organizations and /user/virtual_dns api
  * Added base_url to config and env variables
  * accounts/:id/rules/lists/bulk_operations/:operation_id - syntax fixed
  * Added working GraphQL examples
  * improved debug for jSON based data/params
  * rules,access/logs,access/apps,etc added
  * api decode and Makefile now consistent - no leading slash
  * moved network functions - but forgot one call - now fixed
  * moved network functions into their own file - part of splitting up a large file
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update install requirements
* Thu Jun 25 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.8.3:
  * No upstream changelog
- Add alternative for new manpage.
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 20 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.6.3:
  * No upstream changelog
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 2.3.0
  * no upstream changelog
* Thu Sep 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not install generic examples directory
* Thu Aug 30 2018 mcalabkova@suse.com
- Add the package cloudflare needed by python-certbot subpackage
  * there are no tests on upstream
